/// <reference types="node" />
/// <reference types="node" />
/// <reference types="node" />
import { Dirent } from 'fs';
import { Readable } from 'stream';
import { DiskDriver, ListDirectoryOptions, FileDisk } from 'typefs-registry';
/**
 * Filesystem storage driver
 */
export declare class FileDriver extends DiskDriver {
    protected configuration: FileDisk;
    constructor(c: FileDisk);
    /**
     * Opens file and read full contents of file.
     *
     * @param {string} path relative to root of disk
     * @returns {Promise<Buffer>} contents of file
     * @throws Error when path is outside root directory and
     * configuration.jail is set to true
     */
    read(path: string): Promise<Buffer>;
    /**
     * Opens file and reads the contents of file in chunks.
     *
     * @param {string} path relative to root of disk
     * @returns {Promise<Readable>} contents of file
     * @throws Error when path is outside root directory and
     * configuration.jail is set to true
     */
    readStream(path: string): Promise<Readable>;
    /**
     * Opens file and writes full contents to file.
     *
     * @param {string} path relative to root of disk
     * @param {Buffer} data contents of file
     * @returns {Promise<void>}
     * @throws Error when path is outside root directory and
     * configuration.jail is set to true
     */
    write(path: string, data: Buffer): Promise<void>;
    /**
     * Opens file and writes the contents of file in chunks.
     *
     * @param {string} path relative to root of disk
     * @param {Readable} data contents of file
     * @returns {Promise<void>}
     * @throws Error when path is outside root directory and
     * configuration.jail is set to true
     */
    writeStream(path: string, data: Readable): Promise<void>;
    /**
     * Deletes file.
     *
     * @param {string} path relative to root of disk
     * @returns {Promise<void>}
     * @throws Error when path is outside root directory and
     * configuration.jail is set to true
     */
    deleteFile(path: string): Promise<void>;
    /**
     * Deletes directory.
     *
     * @param {string} path relative to root of disk
     * @returns {Promise<void>}
     * @throws Error when path is outside root directory and
     * configuration.jail is set to true
     */
    deleteDirectory(path: string): Promise<void>;
    /**
     * Creates directory.
     *
     * @param {string} path relative to root of disk
     * @returns {Promise<void>}
     * @throws Error when path is outside root directory and
     * configuration.jail is set to true
     */
    createDirectory(path: string): Promise<void>;
    /**
     * List contents of directory
     *
     * @param {string} path relative to root of disk
     * @param {ListDirectoryOptions} options eg. set recursive to true
     * @returns {Promise<void>}
     * @throws Error when path is outside root directory and
     * configuration.jail is set to true
     */
    listContents(path: string, options?: ListDirectoryOptions): Promise<string[]>;
    /**
     * Checks if file or directory exists.
     *
     * @param {string} path relative to root of disk
     * @returns {Promise<boolean>} true when path exists
     * @throws Error when path is outside root directory and
     * configuration.jail is set to true
     */
    exists(path: string): Promise<boolean>;
    /**
     * When was file last modified.
     *
     * @param {string} path relative to root of disk
     * @returns {Promise<Date>} when file was last modified
     * @throws Error when path is outside root directory and
     * configuration.jail is set to true
     */
    lastModified(path: string): Promise<Date>;
    /**
     * Size of file
     *
     * @param {string} path relative to root of disk
     * @returns {Promise<number>} The file size in bytes
     * @throws Error when path is outside root directory and
     * configuration.jail is set to true
     */
    fileSize(path: string): Promise<number>;
    /**
     * Moves source file to destination
     *
     * @param {string} source path relative to root of disk
     * @param {string} destination path relative to root of disk
     * @returns {Promise<void>}
     * @throws Error when path is outside root directory and
     * configuration.jail is set to true
     */
    move(source: string, destination: string): Promise<void>;
    /**
     * Copies source file to destination
     *
     * @param {string} source path relative to root of disk
     * @param {string} destination path relative to root of disk
     * @returns {Promise<void>}
     * @throws Error when path is outside root directory and
     * configuration.jail is set to true
     */
    copy(source: string, destination: string): Promise<void>;
    /**
     * Controls access to paths which are above/outside the root directory
     *
     * @param {string} path relative path to disks root directory
     * @returns {string} absolute path
     * @throws Error when path is outside root directory and
     * configuration.jail is set to true
     */
    protected jail(path: string): string;
    protected recursiveReadDir(path: string): Array<string>;
    protected filterFiles(path: string, directoryEntities: Dirent[]): Array<string>;
}
